Documentation
¶
Overview ¶
fixadated is a daemon for a collaborative date finding tool.
Copyright (C) 2023 Daniel Steinhauer <d.steinhauer@mailbox.org> This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details. You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
fixadated is a daemon for a collaborative date finding tool.
Copyright (C) 2023 Daniel Steinhauer <d.steinhauer@mailbox.org> This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details. You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
fixadated is a daemon for a collaborative date finding tool.
Copyright (C) 2023 Daniel Steinhauer <d.steinhauer@mailbox.org> This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details. You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
Index ¶
- func GetEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
- func GetRouter() *http.ServeMux
- func NewEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
- func PatchEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
- func PatchParticipationHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
- func RegisterForEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEventHandler ¶
func GetEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
func NewEventHandler ¶
func NewEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
func PatchEventHandler ¶
func PatchEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
func PatchParticipationHandler ¶
func PatchParticipationHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
func RegisterForEventHandler ¶
func RegisterForEventHandler(w http.ResponseWriter, r *http.Request, ps httprouter.Params)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.